#!/usr/bin/env python
#
# Data Quality Checker also known as DQC
#
# Read the README.md for more detailed information
#
#       Barcelona Supercomputing Center - Centro Nacional de Supercomputacion
#       Earth Sciences Department - Computational Earth Sciences
#     
#     Authors: 
#       Joan Sala Calero (joan.sala@bsc.es)
#       Ivan Jose Cernicharo Ortiz (ivan.cernicharo@bsc.es)

import sys
import logging
import os
import subprocess
from cdo import *

# Local import
from utils.utils_files import *

"""
Class: Spatial consistency checks
---
- Uses CDO python bindings
- Checks grid type and resolution
"""
class spatial_consistency_test:

    def __init__(self, logdir, path, gridtype, gridinterval):
        self.testid = 'test04-spatial-consistency'
        self.logdir = logdir          
        self.grid_type = gridtype
        self.grid_int = gridinterval
        self.path = path
        self.files = list_files_folder(path)

    def check_spatial(self):

        # For all files
        cdo = Cdo()
        res = True
        for f in self.files:
            logging.info('Checking {}'.format(f))           
            try:
                info = cdo.griddes(input=f)
            except:
                logging.error('Bad file format (cdo cannot read file)')
                print('ERROR: Bad file format ({})'.format(os.path.basename(f)))
                res = False
                break
                        
            for i in info:
                if 'gridtype' in i:
                    gt = i.split('=')[1].strip()
                if 'xinc' in i:
                    gr = i.split('=')[1].strip()

            if gt != self.grid_type or gr != self.grid_int:
                res = False
                logging.error('Spatial inconsistency found [{} {}] vs [{} {}]'.format(
                    self.grid_type, self.grid_int, gt, gr))
                break

        # Final message
        if res:
            logging.info('FILES ARE SPATIALLY CONSISTENT')
            print('INFO: FILES ARE SPATIALLY CONSISTENT')
        else:
            logging.error('SPATIAL INCONSISTENCIES FOUND')
            print('SPATIAL INCONSISTENCIES FOUND')


    def main(self):

        # Initiate logging
        initiate_logging(self.logdir, self.path, self.testid)           

        self.check_spatial()

if __name__ == "__main__":
    sys.exit()
